# eric7.MicroPython.UnknownDevicesDialog

Module implementing a dialog to manage the list of unknown devices.

### Global Attributes

None

### Classes

UnknownDevicesDialog | Class implementing a dialog to manage the list of unknown devices.

### Functions

None

## UnknownDevicesDialog

Class implementing a dialog to manage the list of unknown devices.

### Derived from

QDialog, Ui_UnknownDevicesDialog

### Class Attributes

DeviceDataRole
ModifiedRole

### Class Methods

None

### Methods

UnknownDevicesDialog | Constructor
__checkButtons | Private slot to set the enabled state of the buttons.
__editItem | Private method to edit the given item.
__isDirty | Private method to check, if the dialog contains unsaved data.
__loadDevices | Private method to load the list of unknown devices.
__saveDeviceData | Private method to save the device data.
on_buttonBox_accepted | Private slot to handle the OK button press.
on_buttonBox_rejected | Private slot handling the cancellation of the dialog.
on_deleteAllButton_clicked | Private slot to delete all devices.
on_deleteButton_clicked | Private slot to delete the selected entries.
on_deviceList_itemActivated | Private slot to edit the data of the activated item.
on_deviceList_itemSelectionChanged | Private slot to handle a change of selected items.
on_editButton_clicked | Private slot to edit the selected item.
on_reportButton_clicked | Private slot to report the data of all boards to the eric-bugs email address.
on_restoreButton_clicked | Private slot to restore the list of unknown devices.

### Static Methods

None

#### UnknownDevicesDialog (Constructor)

UnknownDevicesDialog(parent=None)

Constructor

parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### UnknownDevicesDialog.__checkButtons

__checkButtons()

Private slot to set the enabled state of the buttons.

#### UnknownDevicesDialog.__editItem

__editItem(item)

Private method to edit the given item.

item (QListWidgetItem)
  reference to the item to be edited

#### UnknownDevicesDialog.__isDirty

__isDirty()

Private method to check, if the dialog contains unsaved data.

Return:
  flag indicating the presence of unsaved data

Return Type:
  bool

#### UnknownDevicesDialog.__loadDevices

__loadDevices()

Private method to load the list of unknown devices.

#### UnknownDevicesDialog.__saveDeviceData

__saveDeviceData()

Private method to save the device data.

Return:
  flag indicating a successful save

Return Type:
  bool

#### UnknownDevicesDialog.on_buttonBox_accepted

on_buttonBox_accepted()

Private slot to handle the OK button press.

This action saves the edited list to the preferences store.

#### UnknownDevicesDialog.on_buttonBox_rejected

on_buttonBox_rejected()

Private slot handling the cancellation of the dialog.

#### UnknownDevicesDialog.on_deleteAllButton_clicked

on_deleteAllButton_clicked()

Private slot to delete all devices.

#### UnknownDevicesDialog.on_deleteButton_clicked

on_deleteButton_clicked()

Private slot to delete the selected entries.

#### UnknownDevicesDialog.on_deviceList_itemActivated

on_deviceList_itemActivated(item)

Private slot to edit the data of the activated item.

item (QListWidgetItem)
  reference to the activated item

#### UnknownDevicesDialog.on_deviceList_itemSelectionChanged

on_deviceList_itemSelectionChanged()

Private slot to handle a change of selected items.

#### UnknownDevicesDialog.on_editButton_clicked

on_editButton_clicked()

Private slot to edit the selected item.

#### UnknownDevicesDialog.on_reportButton_clicked

on_reportButton_clicked()

Private slot to report the data of all boards to the eric-bugs email address.

#### UnknownDevicesDialog.on_restoreButton_clicked

on_restoreButton_clicked()

Private slot to restore the list of unknown devices.

Up